@@ -75,7 +75,7 @@ def normalize_bridge_id(bridge_id: str):
     if len(bridge_id) == 12:
         return bridge_id
 
-    logging.getLogger(__name__).warn("Received unexpected bridge id: %s", bridge_id)
+    logging.getLogger(__name__).warning("Received unexpected bridge id: %s", bridge_id)
 
     return bridge_id
 
@@ -135,7 +135,7 @@ def parse_utc_timestamp(datetimestr: str):
 
 
 def _parse_value(name: str, value: Any, value_type: Type, default: Any = MISSING):
-    """Try to parse a value from raw data and type definitions."""
+    """Try to parse a value from raw (json) data and type definitions."""
     if value is None and not isinstance(default, type(MISSING)):
         return default
     if value is None and value_type is NoneType:
@@ -155,6 +155,9 @@ def _parse_value(name: str, value: Any, value_type: Type, default: Any = MISSING
         for sub_arg_type in sub_value_types:
             if value is NoneType and sub_arg_type is NoneType:
                 return value
+            if value == {} and sub_arg_type is NoneType:
+                # handle case where optional value is received as empty dict from api
+                return None
             # try them all until one succeeds
             try:
                 return _parse_value(name, value, sub_arg_type)
@@ -170,7 +173,7 @@ def _parse_value(name: str, value: Any, value_type: Type, default: Any = MISSING
             # raise exception, we have no idea how to handle this value
             raise TypeError(err)
         # failed to parse the (sub) value but None allowed, log only
-        logging.getLogger(__name__).warn(err)
+        logging.getLogger(__name__).debug(err)
         return None
     if value_type is Any:
         return value
@@ -178,14 +181,16 @@ def _parse_value(name: str, value: Any, value_type: Type, default: Any = MISSING
         raise KeyError(f"`{name}` of type `{value_type}` is required.")
     if issubclass(value_type, Enum):
         return value_type(value)
-    if value_type is type(datetime):
+    if value_type is datetime:
         return parse_utc_timestamp(value)
+    if value_type is float and isinstance(value, int):
+        value = float(value)
     if not isinstance(value, value_type):
         raise TypeError(
             f"Value {value} of type {type(value)} is invalid for {name}, "
             f"expected value of type {value_type}"
         )
-    return value_type(value)
+    return value
 
 
 def dataclass_from_dict(cls: dataclass, dict_obj: dict, strict=False):
@@ -199,7 +204,8 @@ def dataclass_from_dict(cls: dataclass, dict_obj: dict, strict=False):
         extra_keys = dict_obj.keys() - set([f.name for f in fields(cls)])
         if extra_keys:
             raise KeyError(
-                "Extra key(s) %s not allowed for %s" % ",".join(extra_keys), (str(cls))
+                "Extra key(s) %s not allowed for %s"
+                % (",".join(extra_keys), (str(cls)))
             )
 
     return cls(
