@@ -4,6 +4,7 @@ import json
 import random
 import string
 from asyncio.coroutines import iscoroutinefunction
+from collections import deque
 from enum import Enum
 from typing import (
     TYPE_CHECKING,
@@ -87,6 +88,7 @@ class EventStream:
         self._bg_tasks: List[asyncio.Task] = []
         self._subscribers: List[EventSubscriptionType] = []
         self._logger = bridge.logger.getChild("events")
+        self._event_history = deque(maxlen=25)
 
     @property
     def connected(self) -> bool:
@@ -98,6 +100,11 @@ class EventStream:
         """Return connection status."""
         return self._status
 
+    @property
+    def last_events(self) -> List[dict]:
+        """Return a list with the previous X messages."""
+        return self._event_history
+
     async def initialize(self) -> None:
         """
         Start listening for events.
@@ -147,7 +154,7 @@ class EventStream:
 
     def emit(self, type: EventType, data: Optional[dict] = None) -> None:
         """Emit event to all listeners."""
-        for (callback, event_filter, resource_filter) in self._subscribers:
+        for callback, event_filter, resource_filter in self._subscribers:
             if event_filter is not None and type not in event_filter:
                 continue
             if (
@@ -265,6 +272,7 @@ class EventStream:
                     if event.get("type") not in ["add", "update", "delete"]:
                         raise InvalidEvent(f"Received invalid event {event}")
                     self._event_queue.put_nowait(event)
+                    self._event_history.append(event)
                 return
             if key != "data":
                 self._logger.debug("Received unexpected message: %s - %s", key, value)
@@ -278,11 +286,13 @@ class EventStream:
         # Oh yeah, this is a major hack and hopefully it will only be temporary ;-)
         # Signify forgot to implement some sort of periodic keep alive message on the EventBus
         # so we have no way to determine if the connection is still alive.
-        # To workaround this, we create a geofence client (without a status)
+        # To workaround this, we create a geofence client (with status not at home)
         # on the bridge for aiohue which will have its name updated every minute
         # this will result in an event on the eventstream and thus a way to figure out
         # if its still alive. It's not very pretty but at least it works.
         # Now let's contact Signify if this can be solved.
+        # Update 2022-12-12: Still no solution and apparently no real need for signify to fix this
+        # https://developers.meethue.com/forum/t/several-issues-and-questions-about-the-v2-api/6586/35
         prefix = "aiohue_"
 
         while True:
@@ -295,7 +305,7 @@ class EventStream:
                         break
                 else:
                     await self._bridge.sensors.geofence_client.create(
-                        GeofenceClientPost(name=prefix)
+                        GeofenceClientPost(name=prefix, is_at_home=False)
                     )
                     continue
 
@@ -305,7 +315,8 @@ class EventStream:
                     (random.choice(string.ascii_lowercase)) for x in range(10)
                 )
                 await self._bridge.sensors.geofence_client.update(
-                    hass_client.id, GeofenceClientPut(name=f"{prefix}{random_str}")
+                    hass_client.id,
+                    GeofenceClientPut(name=f"{prefix}{random_str}", is_at_home=False),
                 )
             except (ClientError, asyncio.TimeoutError, AiohueException) as err:
                 # might happen on connection error, we don't want the retry logic to bail out
