@@ -1,5 +1,6 @@
 """Controller holding and managing HUE resources of type `light`."""
-from typing import Optional, Tuple, Type
+
+from typing import Optional, Tuple, Type, Union
 
 from ..models.feature import (
     AlertEffectType,
@@ -9,7 +10,11 @@ from ..models.feature import (
     ColorTemperatureFeaturePut,
     DimmingFeaturePut,
     DynamicsFeaturePut,
+    EffectsFeaturePut,
+    EffectStatus,
     OnFeature,
+    TimedEffectStatus,
+    TimedEffectsFeaturePut,
 )
 from ..models.light import Light, LightPut
 from ..models.resource import ResourceTypes
@@ -60,7 +65,7 @@ class LightsController(BaseResourcesController[Type[Light]]):
             device = self.get_device(id)
             await self._bridge.devices.set_identify(device.id)
         else:
-            await self.set_state(id, on=True, alert=AlertEffectType.BREATHE)
+            await self.set_state(id, alert=AlertEffectType.BREATHE)
 
     async def set_state(
         self,
@@ -71,6 +76,7 @@ class LightsController(BaseResourcesController[Type[Light]]):
         color_temp: Optional[int] = None,
         transition_time: Optional[int] = None,
         alert: Optional[AlertEffectType] = None,
+        effect: Union[EffectStatus, TimedEffectStatus, None] = None,
     ) -> None:
         """Set supported feature(s) to light resource."""
         update_obj = LightPut()
@@ -82,8 +88,16 @@ class LightsController(BaseResourcesController[Type[Light]]):
             update_obj.color = ColorFeaturePut(xy=ColorPoint(*color_xy))
         if color_temp is not None:
             update_obj.color_temperature = ColorTemperatureFeaturePut(mirek=color_temp)
-        if transition_time is not None:
+        if transition_time is not None and effect is None:
             update_obj.dynamics = DynamicsFeaturePut(duration=transition_time)
         if alert is not None:
             update_obj.alert = AlertFeaturePut(action=alert)
+
+        # for timed_effects feature, transition time is used for duration
+        if effect is not None and isinstance(effect, TimedEffectStatus):
+            update_obj.timed_effects = TimedEffectsFeaturePut(
+                effect=effect, duration=transition_time
+            )
+        elif effect is not None:
+            update_obj.effects = EffectsFeaturePut(effect=effect)
         await self.update(id, update_obj)
