@@ -5,6 +5,7 @@ from typing import TYPE_CHECKING, Dict, Optional, Type, Union
 from aiohue.util import dataclass_to_dict
 
 from ..models.button import Button, ButtonEvent
+from ..models.relative_rotary import RelativeRotary
 from ..models.device_power import DevicePower
 from ..models.geofence_client import GeofenceClient
 from ..models.light_level import LightLevel, LightLevelPut
@@ -24,6 +25,7 @@ SENSOR_TYPES = Union[
     GeofenceClient,
     LightLevel,
     Motion,
+    RelativeRotary,
     Temperature,
     ZigbeeConnectivity,
 ]
@@ -49,17 +51,19 @@ class ButtonController(BaseResourcesController[Type[Button]]):
     _workaround_tasks: Dict[str, asyncio.Task] = None
 
     async def _handle_event(
-        self, evt_type: EventType, evt_data: Optional[dict], skip_forward: bool = False
+        self, evt_type: EventType, evt_data: Optional[dict]
     ) -> None:
         """Handle incoming event for this resource from the EventStream."""
         await super()._handle_event(evt_type, evt_data)
 
+        if not evt_data:
+            return
+
         # Handle longpress workaround if needed
-        if (
-            not evt_data
-            or evt_type != EventType.RESOURCE_UPDATED
-            or not evt_data.get("button")
-            or evt_data["button"].get("last_event") != ButtonEvent.INITIAL_PRESS
+        if not (
+            evt_type == EventType.RESOURCE_UPDATED
+            and evt_data.get("button", {}).get("last_event")
+            == ButtonEvent.INITIAL_PRESS.value
         ):
             return
 
@@ -70,12 +74,11 @@ class ButtonController(BaseResourcesController[Type[Button]]):
         if self._workaround_tasks is None:
             self._workaround_tasks = {}
 
-        if evt_data["id"] in self._workaround_tasks:
-            # cancel existing task (if any)
-            # should not happen, but just in case
-            task = self._workaround_tasks.pop(evt_data["id"])
-            if not task.done():
-                task.cancel()
+        # cancel existing task (if any)
+        # should not happen, but just in case
+        task = self._workaround_tasks.pop(evt_data["id"], None)
+        if task and not task.done():
+            task.cancel()
 
         self._workaround_tasks[evt_data["id"]] = asyncio.create_task(
             self._handle_longpress_workaround(evt_data["id"])
@@ -86,6 +89,7 @@ class ButtonController(BaseResourcesController[Type[Button]]):
         # Fake `held down` and `long press release` events.
         # This might need to be removed in a future release once/if Signify
         # adds this back in their API.
+        self._logger.debug("Long press workaround for FOH switch initiated.")
         btn_resource = dataclass_to_dict(self._items[id])
         await asyncio.sleep(1.5)  # time to initially wait for SHORT_RELEASE
         count = 0
@@ -108,6 +112,7 @@ class ButtonController(BaseResourcesController[Type[Button]]):
             if count > 1:
                 btn_resource["button"]["last_event"] = ButtonEvent.LONG_RELEASE.value
                 await self._handle_event(EventType.RESOURCE_UPDATED, btn_resource)
+            self._logger.debug("Long press workaround for FOH switch completed.")
 
 
 class GeofenceClientController(BaseResourcesController[Type[GeofenceClient]]):
@@ -142,6 +147,14 @@ class MotionController(BaseResourcesController[Type[Motion]]):
         await self.update(id, MotionPut(enabled=enabled))
 
 
+class RelativeRotaryController(BaseResourcesController[Type[Button]]):
+    """Controller holding and managing HUE resources of type `relative_rotary`."""
+
+    item_type = ResourceTypes.RELATIVE_ROTARY
+    item_cls = RelativeRotary
+    allow_parser_error = True
+
+
 class TemperatureController(BaseResourcesController[Type[Temperature]]):
     """Controller holding and managing HUE resources of type `temperature`."""
 
@@ -168,6 +181,7 @@ class SensorsController(GroupedControllerBase[SENSOR_TYPES]):
         self.geofence_client = GeofenceClientController(bridge)
         self.light_level = LightLevelController(bridge)
         self.motion = MotionController(bridge)
+        self.relative_rotary = RelativeRotaryController(bridge)
         self.temperature = TemperatureController(bridge)
         self.zigbee_connectivity = ZigbeeConnectivityController(bridge)
         super().__init__(
@@ -178,6 +192,7 @@ class SensorsController(GroupedControllerBase[SENSOR_TYPES]):
                 self.geofence_client,
                 self.light_level,
                 self.motion,
+                self.relative_rotary,
                 self.temperature,
                 self.zigbee_connectivity,
             ],
