@@ -12,17 +12,25 @@ from .feature import (
     AlertFeaturePut,
     ColorFeature,
     ColorFeatureBase,
+    ColorTemperatureDeltaFeaturePut,
     ColorTemperatureFeature,
     ColorTemperatureFeatureBase,
+    DimmingDeltaFeaturePut,
     DimmingFeature,
     DimmingFeatureBase,
     DynamicsFeature,
     DynamicsFeaturePut,
     DynamicStatus,
     EffectsFeature,
+    EffectsFeaturePut,
     GradientFeature,
     GradientFeatureBase,
     OnFeature,
+    PowerUpFeature,
+    PowerUpFeaturePut,
+    SignalingFeature,
+    TimedEffectsFeature,
+    TimedEffectsFeaturePut,
 )
 from .resource import ResourceIdentifier, ResourceTypes
 
@@ -61,7 +69,6 @@ class Light:
 
     id: str
     owner: ResourceIdentifier
-    metadata: LightMetaData
     on: OnFeature
     mode: LightMode
 
@@ -71,8 +78,11 @@ class Light:
     color: Optional[ColorFeature] = None
     dynamics: Optional[DynamicsFeature] = None
     alert: Optional[AlertFeature] = None
+    signaling: Optional[SignalingFeature] = None
     gradient: Optional[GradientFeature] = None
     effects: Optional[EffectsFeature] = None
+    timed_effects: Optional[TimedEffectsFeature] = None
+    powerup: Optional[PowerUpFeature] = None
 
     type: ResourceTypes = ResourceTypes.LIGHT
 
@@ -91,13 +101,6 @@ class Light:
         """Return if this light supports color_temperature control."""
         return self.color_temperature is not None
 
-    @property
-    def name(self) -> Optional[str]:
-        """Return name from metadata."""
-        if self.metadata is not None:
-            return self.metadata.name
-        return None
-
     @property
     def is_on(self) -> bool:
         """Return bool if light is currently powered on."""
@@ -135,8 +138,13 @@ class LightPut:
 
     on: Optional[OnFeature] = None
     dimming: Optional[DimmingFeatureBase] = None
+    dimming_delta: Optional[DimmingDeltaFeaturePut] = None
     color_temperature: Optional[ColorTemperatureFeatureBase] = None
+    color_temperature_delta: Optional[ColorTemperatureDeltaFeaturePut] = None
     color: Optional[ColorFeatureBase] = None
     dynamics: Optional[DynamicsFeaturePut] = None
     alert: Optional[AlertFeaturePut] = None
     gradient: Optional[GradientFeatureBase] = None
+    effects: Optional[EffectsFeaturePut] = None
+    timed_effects: Optional[TimedEffectsFeaturePut] = None
+    powerup: Optional[PowerUpFeaturePut] = None
