@@ -56,7 +56,7 @@ class RoomArchetype(Enum):
     OTHER = "other"
 
     @classmethod
-    def _missing_(cls: Type, value: str):
+    def _missing_(cls: Type, value: object):
         """Set default enum member if an unknown value is provided."""
         return RoomArchetype.OTHER
 
@@ -112,11 +112,6 @@ class Room:
         """Return set of device id's that belong to this room."""
         return {x.rid for x in self.children}
 
-    @property
-    def lights(self) -> Set[str]:
-        """Return a set of light id's belonging to this zone."""
-        return {x.rid for x in self.services if x.rtype == ResourceTypes.LIGHT}
-
     @property
     def grouped_light(self) -> Optional[str]:
         """Return the grouped light id that is connected to this room (if any)."""
@@ -126,3 +121,27 @@ class Room:
             (x.rid for x in self.services if x.rtype == ResourceTypes.GROUPED_LIGHT),
             None,
         )
+
+
+@dataclass
+class RoomPut:
+    """
+    Properties to send when updating/setting a `Room` object on the api.
+
+    https://developers.meethue.com/develop/hue-api-v2/api-reference/#resource_room__id__put
+    """
+
+    children: Optional[List[ResourceIdentifier]] = None
+    metadata: Optional[RoomMetaDataPut] = None
+
+
+@dataclass
+class RoomPost:
+    """
+    Properties to send when creating a `Room` object on the api.
+
+    https://developers.meethue.com/develop/hue-api-v2/api-reference/#resource_room_post
+    """
+
+    children: List[ResourceIdentifier]
+    metadata: RoomMetaData
